@@ -1,4 +1,5 @@
 context("Running max")
+suppressWarnings(RNGversion("3.5.0"))
 set.seed(11)
 x1 <- sample(c(1,2,3), 15, replace=T)
 x2 <- sample(c(NA,1,2,3), 15, replace=T)
@@ -63,7 +64,43 @@ test_that("varying window", {
 
 })
 
+
+test_that("max_run with idx++ same as max_run with windows",{
+  expect_identical( max_run(x1,k=3) , max_run(x1,k=3, idx=1:15) )
+  expect_identical( max_run(x1,k=k) , max_run(x1,k=k, idx=1:15) )
+})
+
+test_that("max_run with idx",{
+  x11 <- rep(NA, 15)
+  x22 <- rep(NA, 15)
+  idx <- cumsum(sample(c(1,2,3,4), 15, replace=T))
+
+  for(i in 1:15)
+    for(j in i:1)
+      if(idx[j] >= (idx[i]-2)){
+        x11[i] <- max(x1[j:i])
+      } else {
+        break;
+      }
+
+
+  for(i in 1:15)
+    for(j in i:1)
+      if(idx[j] >= (idx[i]-(k[i]-1))){
+        x22[i] <- max(x1[j:i])
+      } else {
+        break;
+      }
+
+  expect_identical(max_run(x1, k=3, idx=idx), x11)
+  expect_identical(max_run(x1, k=k, idx=idx), x22)
+
+})
+
+
 test_that("Error handling in max_run",{
   expect_error(max_run(x2, k=c(2,2,2,2,NA)))
   expect_error(max_run(x2, k=c(2,2,2,2,2,2)))
 })
+
+
